==> khweeteur_0.0.52-1.tar.gz: khweeteur-0.0.52/khweeteur/usr/lib/python2.5/site-packages/khweeteur/notifications.py <==
#!/usr/bin/env python2.5
# -*- coding: utf-8 -*-
#
# Copyright (c) 2010 Benot HERVIER
# Licenced under GPLv3

from PyQt4.QtGui import *
from PyQt4.QtCore import *


try:
    from PyQt4.QtMobility.QtLocation import *
#    from PySide.QtMobility.QtLocation import *
    noQtLocation = False
except:
    noQtLocation = True

try:
    from PyQt4.QtMaemo5 import *
#    from PySide.QtMaemo5 import *
    isMAEMO = True
except:
    isMAEMO = False


try:
    import dbus
    import dbus.service
    from dbus.mainloop.qt import DBusQtMainLoop
    from dbusobj import KhweeteurDBus
    noDBUS = False
except:
    noDBUS = True

class KhweeteurNotification(QObject):
    '''Notification class interface'''
    def __init__(self):
        global noDBUS
        QObject.__init__(self)
        if not noDBUS:
	    try:
		    self.m_bus = dbus.SystemBus()
		    self.m_notify = self.m_bus.get_object('org.freedesktop.Notifications',
							  '/org/freedesktop/Notifications')
		    self.iface = dbus.Interface(self.m_notify, 'org.freedesktop.Notifications')
		    self.m_id = 0
	    except:            
             noDBUS = True 

    def warn(self, message):
        '''Display an Hildon banner'''
        if not noDBUS:
            if isMAEMO:
                try:
                    self.iface.SystemNoteDialog(message,0, 'Nothing')
                except:
                    pass

    def info(self, message):
        '''Display an information banner'''
        if not noDBUS:
            if isMAEMO:
                try:
                    self.iface.SystemNoteInfoprint('Khweeteur : '+message)
                except:
                    pass

    def notify(self,title, message,category='im.received', icon='khweeteur',count=1):
        '''Create a notification in the style of email one'''
        if not noDBUS:
            try:
                self.m_id = self.iface.Notify('Khweeteur',
                                  self.m_id,
                                  icon,
                                  title,
                                  message,
                                  ['default','call'],
                                  {'category':category,
                                  'desktop-entry':'khweeteur',
                                  'dbus-callback-default':'net.khertan.khweeteur /net/khertan/khweeteur net.khertan.khweeteur show_now',
                                  'count':count,
                                  'amount':count},
                                  -1
                                  )
            except:
                pass

==> khweeteur_0.1.6-2.tar.gz: khweeteur-0.1.6/khweeteur/usr/lib/python2.5/site-packages/khweeteur/notifications.py <==
#!/usr/bin/env python2.5
# -*- coding: utf-8 -*-
#
# Copyright (c) 2010 Benoît HERVIER
# Licenced under GPLv3

from utils import *

if not USE_PYSIDE:
    from PyQt4.QtCore import QObject
else:
    from PySide.QtCore import QObject
    
try:
    import dbus
    import dbus.service
    from dbus.mainloop.qt import DBusQtMainLoop
    from dbusobj import KhweeteurDBus
    noDBUS = False
except:
    noDBUS = True
    print 'No dbus try with pynotify'
    import pynotify
    
class KhweeteurNotification(QObject):
    '''Notification class interface'''
    def __init__(self):
        global noDBUS
        QObject.__init__(self)
        if not noDBUS:
            try:
                self.m_bus = dbus.SystemBus()
                self.m_notify = self.m_bus.get_object('org.freedesktop.Notifications',
                                  '/org/freedesktop/Notifications')
                self.iface = dbus.Interface(self.m_notify, 'org.freedesktop.Notifications')
                self.m_id = 0
            except:
                 noDBUS = True

    def warn(self, message):
        '''Display an Hildon banner'''
        if not noDBUS:
            if isMAEMO:
                try:
                    self.iface.SystemNoteDialog(message,0, 'Nothing')
                except:
                    pass
        else:
            if pynotify.init("Khweeteur"):
                n = pynotify.Notification(message, message)
                n.show()
                
    def info(self, message):
        '''Display an information banner'''
        if not noDBUS:
            if isMAEMO:
                try:
                    self.iface.SystemNoteInfoprint('Khweeteur : '+message)
                except:
                    pass
        else:
            if pynotify.init("Khweeteur"):
                n = pynotify.Notification(message, message)
                n.show()
                
    def notify(self,title, message,category='khweeteur-new-tweets', icon='khweeteur',count=1):
        '''Create a notification in the style of email one'''
        if not noDBUS:
            try:
                self.m_id = self.iface.Notify('Khweeteur',
                                  self.m_id,
                                  icon,
                                  title,
                                  message,
                                  ['default','call'],
                                  {'category':category,
                                  'desktop-entry':'khweeteur',
                                  'dbus-callback-default':'net.khertan.khweeteur /net/khertan/khweeteur net.khertan.khweeteur show_now',
                                  'count':count,
                                  'amount':count},
                                  -1
                                  )
            except:
                pass
                
        else:
            if pynotify.init("Khweeteur"):
                n = pynotify.Notification(title, message)
                n.show()
